@@ -40,7 +40,7 @@ static gint lang_num = 0;
 const gchar *
 trans_code_to_country (gchar *code)
 {
-#	define COUNTRY_N 40
+#	define COUNTRY_N 50
 	gsize i;
 	gchar *dummy = NULL;
 	static gchar map[COUNTRY_N][2][64] = {
@@ -69,11 +69,13 @@ trans_code_to_country (gchar *code)
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
 		{"kk","Қазақстан"},
+		{"kr","대한민국"}, /* Korea */
 		{"no","Norge"},
 		{"pl","Polska"},
 		{"pk","پاکستان"},
-		{"pt","Portugal"},
-		{"ru","Россия"}, /* 30 */
+		{"pt","Portugal"}, /* 30 */
+		{"rs","Србија"}, /* Serbia */
+		{"ru","Россия"},
 		{"sl","Slovenija"},
 		{"se","Sverige"},
 		{"tr","Türkiye"},
@@ -81,6 +83,14 @@ trans_code_to_country (gchar *code)
 		{"uk","United Kingdom"},
 		{"us","USA"},
 		{"",""},
+		{"",""}, /* 40 */
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
 		{"",""},
 		{"",""},
 		{"",""}
@@ -471,7 +481,8 @@ trans_change_language (gchar *language)
 	gint i;
 	gchar *tmp_code;
 
-	for (i = 0; i < lang_num; i++)
+	/* Keep decreasing order of scanning, for not missing "English UK", for instance. */
+	for (i = lang_num-1; i >= 0; i--)
 		if (g_str_has_prefix (language, lang[i].name))
 			break;
 
@@ -706,5 +717,6 @@ trans_read_text (const gchar * file_end)
 		}
 	}
 	buf[pos] = 0;
+	fclose (fh);
 	return buf;
 }
