@@ -11,12 +11,12 @@
 /*****************************************************************************/
 
 /*
- * This file contains the set of languages configured for
- * internationalization.
+ * This definition contains the set of languages configured for
+ * localization.
  * The letters in parenthesis must agree with LL_CC,
  * where LL is the language code
  * and CC is the country code.
- * The only one exception is for the generic
+ * The only exception is for the generic
  * English, which uses the 'C' code.
  * Keep the alphabetic order, because it is put
  * in the interface as done here.
@@ -42,15 +42,17 @@
 "Hrvatski (hr) [qwertz_hr]\n" \
 "Italiano (it) [qwerty_it]\n" \
 "Қазақ (kk) [jtsuken_kk]\n" \
+"한국어 (ko) [dubeolsik_kr]\n" \
 "Кыргызча (ky) [jtsuken_ru]\n" \
 "Magyar (hu) [qwertz_hu]\n" \
 "Nederlands (nl) [qwerty_us]\n" \
-"Punjabi (pa) [gumurkhi_in_jehlum]\n" \
+"ਪੰਜਾਬੀ (pa) [gumurkhi_in_jehlum]\n" \
 "Polski (pl) [qwerty_pl_us]\n" \
 "Português (pt_BR) [qwerty_br_abnt2]\n" \
 "Русский (ru) [jtsuken_ru]\n" \
-"Suomen kieli (fi) [querty_se]\n"\
+"Suomen kieli (fi) [qwerty_se]\n"\
 "Slovenščina (sl) [qwertz_sl]\n" \
+"Српски (sr) [qwertz_rs]\n" \
 "Svenska (sv) [qwerty_se]\n" \
 "తెలుగు (te) [qwerty_us]\n" \
 "Українська (uk) [jtsuken_ua]\n" \
