@@ -749,7 +749,8 @@ tutor_eval_forward (gunichar user_chr)
 		return (TRUE);
 	}
 
-	tutor.n_touchs++;
+	gsize n_touchs = g_unichar_fully_decompose (user_chr, FALSE, NULL, 0);
+	tutor.n_touchs += (int) n_touchs;
 
 	real_chr = cursor_get_char ();
 
@@ -781,7 +782,7 @@ tutor_eval_forward (gunichar user_chr)
 			accur_wrong (real_chr);
 
 		cursor_paint_char ("char_wrong");
-		tutor.n_errors++;
+		tutor.n_errors += (int) n_touchs;
 		tutor_beep ();
 	}
 
@@ -873,7 +874,8 @@ tutor_eval_forward_backward (gunichar user_chr)
 	 */
 	if (user_chr == real_chr && tutor.retro_pos == 0)
 	{
-		tutor.n_touchs++;
+	        gsize n_touchs = g_unichar_fully_decompose (user_chr, FALSE, NULL, 0);
+	        tutor.n_touchs += (int) n_touchs;
 		if (tutor.ttidx < MAX_TOUCH_TICS)
 		{
 			tutor.touch_time[tutor.ttidx] =
@@ -884,7 +886,7 @@ tutor_eval_forward_backward (gunichar user_chr)
 		if (tutor.correcting != 0)
 		{
 			cursor_paint_char ("char_retouched");
-			tutor.n_errors++;
+			tutor.n_errors += (int) n_touchs;
 		}
 		else
 		{
